@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,10 +22,10 @@
 
 #include <QDialog>
 #include "gravatar_export.h"
-class QCheckBox;
-class QPushButton;
-class KPluralHandlingSpinBox;
 namespace Gravatar {
+class GravatarConfigureSettingsWidget;
+
+/** Gravatar settings dialog. */
 class GRAVATAR_EXPORT GravatarConfigureSettingsDialog : public QDialog
 {
     Q_OBJECT
@@ -35,12 +35,9 @@ public:
 
 private:
     void slotRestoreDefault();
-    void slotClearGravatarCache();
     void save();
     void load();
-    QCheckBox *mUseDefaultPixmap = nullptr;
-    QPushButton *mClearGravatarCache = nullptr;
-    KPluralHandlingSpinBox *mGravatarCacheSize = nullptr;
+    GravatarConfigureSettingsWidget *mGravatarConfigureSettings;
 };
 }
 
